# AWGAN
Codes for paper: AWGAN: A Powerful Batch Effect Removal Model for scRNA-seq Data

# Download
To install this tool, please use this code:
```
pip install awgan
```

# Package Requirement

To run AWGAN and other benchmarks, we suggest you install the python environment with the version-specific package listed in this table. 

|                 | Package    | Version |
|-----------------|------------|---------|
| Python packages | pytorch    | 1.9.0   |
|                 | scanpy     | 1.8.1   |
|                 | scIB       | 0.1.1   |
|                 | scprep     | 1.1.0   |
|                 | umap-learn | 0.5.1   |
|                 | phate      | 1.0.7   |
|                 | imap       | 1.0.0   |
|                 | scVI       | 0.6.8   |
|                 | bbknn      | 1.5.1   |
|                 | mnnpy      | 0.1.9.5 |
|                 | Harmonypy  | 0.0.5   |
|                 | rpy2       | 3.4.5   |
| R packages      | kBET       | 0.99.6  |
|                 | LISI       | 1.0.0   |
|                 | liger      | 1.0.0   |
|                 | Seurat     | 4.0.6   |

# Reference
Please use:

AWGAN: A Powerful Batch Correction Model for scRNA-seq Data.
Tianyu Liu, Yuge Wang, Hong-yu Zhao. bioRxiv 2021.11.08.467781; doi: https://doi.org/10.1101/2021.11.08.467781
